@@ -14,6 +14,7 @@ if (!defined("_ECRIRE_INC_VERSION")) return;
 
 include_spip('inc/minipres');
 include_spip('inc/install');
+include_spip('inc/autoriser');
 
 define("_ECRIRE_INSTALL", "1");
 define('_FILE_TMP', '_install');
@@ -22,7 +23,7 @@ define('_FILE_TMP', '_install');
 function exec_install_dist()
 {
 	$etape = _request('etape');
-	if (_FILE_CONNECT AND (!in_array($etape, array('chmod', 'sup1', 'sup2')))) {
+	if (_FILE_CONNECT  AND (!in_array($etape, array('chmod', 'sup1', 'sup2')) OR !autoriser('configurer'))) {
   // L'etape chmod peut etre reexecutee n'importe quand apres l'install,
   // pour verification des chmod. Sinon, install deja faite => refus.
 		echo minipres();
