@@ -46,15 +46,9 @@ function copie_locale($source, $mode='auto') {
 	AND preg_match(',^\w+://,', $source)) {
 		if (($mode=='auto' AND !@file_exists(_DIR_RACINE.$local))
 		OR $mode=='force') {
-			$contenu = recuperer_page($source,false,false,_COPIE_LOCALE_MAX_SIZE);
-			if (!$contenu) return false;
-			if (preg_match(',[.](jpg|gif|png)$,i',$local) 
-			  AND strlen($contenu)>_COPIE_LOCALE_MAX_SIZE){
-			  spip_log ('ERREUR copie locale image '._DIR_RACINE.$local.' superieure a  '._COPIE_LOCALE_MAX_SIZE);
-			  return false;
-			}
-			ecrire_fichier(_DIR_RACINE.$local, $contenu);
-			spip_log ('ecrire copie locale '._DIR_RACINE.$local);
+			$res = recuperer_page($source,_DIR_RACINE.$local,false,_COPIE_LOCALE_MAX_SIZE);
+			if (!$res) return false;
+			spip_log ('ecrire copie locale '._DIR_RACINE.$local." taille $res");
 			
 			// pour une eventuelle indexation
 			pipeline('post_edition',
@@ -161,12 +155,23 @@ function prepare_donnees_post($donnees, $boundary = '') {
 // et refuser_gz pour forcer le refus de la compression (cas des serveurs orthographiques)
 // date_verif, un timestamp unix pour arreter la recuperation si la page distante n'a pas ete modifiee depuis une date donnee
 // uri_referer, preciser un referer different
+// Le second argument ($trans) :
+// * si c'est une chaine longue, alors c'est un nom de fichier
+//   dans lequel on ecrit directement la page
+// * si c'est true/null ca correspond a une demande d'encodage/charset
 // http://doc.spip.org/@recuperer_page
-function recuperer_page($url, $munge_charset=false, $get_headers=false,
-	$taille_max = 1048576, $datas='', $boundary='', $refuser_gz = false,
+function recuperer_page($url, $trans=false, $get_headers=false,
+	$taille_max = null, $datas='', $boundary='', $refuser_gz = false,
 	$date_verif = '', $uri_referer = '') {
-  	$gz = false;
-  // Accepter les URLs au format feed:// ou qui ont oublie le http://
+	$gz = false;
+
+	// $copy = copier le fichier ?
+	$copy = (is_string($trans) AND strlen($trans) > 5); // eviter "false" :-)
+
+	if (is_null($taille_max))
+		$taille_max = $copy ? _COPIE_LOCALE_MAX_SIZE : 1048576;
+
+	// Accepter les URLs au format feed:// ou qui ont oublie le http://
 	$url = preg_replace(',^feed://,i', 'http://', $url);
 	if (!preg_match(',^[a-z]+://,i', $url)) $url = 'http://'.$url;
 
@@ -183,7 +188,7 @@ function recuperer_page($url, $munge_charset=false, $get_headers=false,
 
 	// dix tentatives maximum en cas d'entetes 301...
 	for ($i=0;$i<10;$i++) {
-		$url = recuperer_lapage($url, $munge_charset, $get, $taille_max, $datas, $boundary, $refuser_gz, $date_verif, $uri_referer);
+		$url = recuperer_lapage($url, $trans, $get, $taille_max, $datas, $boundary, $refuser_gz, $date_verif, $uri_referer);
 		if (!$url) return false;
 		if (is_array($url)) {
 			list($headers, $result) = $url;
@@ -194,10 +199,19 @@ function recuperer_page($url, $munge_charset=false, $get_headers=false,
 
 // args comme ci-dessus (presque)
 // retourne l'URL en cas de 301, un tableau (entete, corps) si ok, false sinon
-
+// si $trans est null -> on ne veut que les headers
+// si $trans est une chaine, c'est un nom de fichier pour ecrire directement dedans
 // http://doc.spip.org/@recuperer_lapage
 function recuperer_lapage($url, $trans=false, $get='GET', $taille_max = 1048576, $datas='', $boundary='', $refuser_gz = false, $date_verif = '', $uri_referer = '')
 {
+	// $copy = copier le fichier ?
+	$copy = (is_string($trans) AND strlen($trans) > 5); // eviter "false" :-)
+
+	// si on ecrit directement dans un fichier, pour ne pas manipuler
+	// en memoire refuser gz
+	if ($copy)
+		$refuser_gz = true;
+
 	// ouvrir la connexion et envoyer la requete et ses en-tetes
 	list($f, $fopen) = init_http($get, $url, $refuser_gz, $uri_referer, $datas);
 	if (!$f) {
@@ -226,7 +240,7 @@ function recuperer_lapage($url, $trans=false, $get='GET', $taille_max = 1048576,
 
 #	spip_log("recup  $headers" );
 	if ($trans === NULL) return array($headers, '');
-	$result = recuperer_body($f, $taille_max);
+	$result = recuperer_body($f, $taille_max, $copy ? $trans : '');
 	fclose($f);
 	if (!$result) return array($headers, $result);
 
@@ -235,7 +249,7 @@ function recuperer_lapage($url, $trans=false, $get='GET', $taille_max = 1048576,
 		$result = spip_gzinflate_body($result);
 	}
 	// Faut-il l'importer dans notre charset local ?
-	if ($trans) {
+	if ($trans === true) {
 		include_spip('inc/charsets');
 		$result = transcoder_page ($result, $headers);
 	}
@@ -243,36 +257,41 @@ function recuperer_lapage($url, $trans=false, $get='GET', $taille_max = 1048576,
 	return array($headers, $result);
 }
 
-// Certaines decompressions gz sont subtiles
-// cf. http://fr2.php.net/manual/fr/function.gzinflate.php#77336
-// (cas de http://files.spip.org/spip-zone/paquets.xml.gz qui ne pouvait etre recupere)
 // http://doc.spip.org/@spip_gzinflate_body
 function spip_gzinflate_body($gzData){
-	// return gzinflate(substr($gzData,10));
-    if(substr($gzData,0,3)=="\x1f\x8b\x08"){
-        $i=10;
-        $flg=ord(substr($gzData,3,1));
-        if($flg>0){
-            if($flg&4){
-                list($xlen)=unpack('v',substr($gzData,$i,2));
-                $i=$i+2+$xlen;
-            }
-            if($flg&8) $i=strpos($gzData,"\0",$i)+1;
-            if($flg&16) $i=strpos($gzData,"\0",$i)+1;
-            if($flg&2) $i=$i+2;
-        }
-        return gzinflate(substr($gzData,$i,-8));
-    }
-    else return false;
+	// on dezippe via un fichier temporaire
+	// sinon la memoire explose pour les gros flux
+	$tmp = _DIR_TMP.md5(uniqid()).'.tmp';
+	ecrire_fichier($tmp, $gzData);
+	rename($tmp,$tmp.'.gz');
+	lire_fichier($tmp.'.gz', $gzData);
+	supprimer_fichier($tmp.'.gz');
+	return $gzData;
 }
 
 
 // http://doc.spip.org/@recuperer_body
-function recuperer_body($f, $taille_max=1048576)
+function recuperer_body($f, $taille_max=1048576, $fichier='')
 {
+	$taille = 0;
 	$result = '';
-	while (!feof($f) AND strlen($result)<$taille_max)
-		$result .= fread($f, 16384);
+	if ($fichier){
+		$fp = spip_fopen_lock($fichier, 'w',LOCK_EX);
+		if (!$fp) return false;
+		$result = 0; // on renvoie la taille du fichier
+	}
+	while (!feof($f) AND $taille<$taille_max){
+		$res = fread($f, 16384);
+		$taille += strlen($res);
+		if ($fp){
+			fwrite($fp,$res);
+			$result = $taille;
+		}
+		else
+			$result .= $res;
+	}
+	if ($fp)
+		spip_fclose_unlock($fp);
 	return $result;
 }
 
@@ -354,6 +373,7 @@ function fichier_copie_locale($source) {
 	$path_parts = pathinfo($source);
 	$ext = $path_parts ? $path_parts['extension'] : '';
 	if ($ext
+		AND preg_match(',^\w+$,',$ext) // pas de php?truc=1&...
 	  AND $f=nom_fichier_copie_locale($source, $ext)
 	  AND file_exists(_DIR_RACINE . $f))
 	  return $f;
@@ -409,8 +429,8 @@ function recuperer_infos_distantes($source, $max=0, $charger_si_petite_image = t
 	// On va directement charger le debut des images et des fichiers html,
 	// de maniere a attrapper le maximum d'infos (titre, taille, etc). Si
 	// ca echoue l'utilisateur devra les entrer...
-	if ($headers = recuperer_page($source, false, true, $max)) {
-		list($headers, $a['body']) = split("\n\n", $headers, 2);
+	if ($headers = recuperer_page($source, false, true, $max, '', '', true)) {
+		list($headers, $a['body']) = preg_split(',\n\n,', $headers, 2);
 
 		if (preg_match(",\nContent-Type: *([^[:space:];]*),i", "\n$headers", $regs))
 			$mime_type = (trim($regs[1]));
@@ -536,16 +556,14 @@ function init_http($method, $url, $refuse_gz=false, $referer = '', $datas="", $v
 	else {
 		$scheme = $t['scheme']; $noproxy = $scheme.'://';
 	}
-	if (isset($t['user'])) {
-		$scheme_fsock .= $t['user'];
-		if (isset($t['pass'])) $scheme_fsock .= ':'.$t['pass'];
-		$scheme_fsock .= '@';
-	}
+	if (isset($t['user']))
+		$user = array($t['user'], $t['pass']);
+
 	if (!isset($t['port']) || !($port = $t['port'])) $port = 80;
 	if (!isset($t['path']) || !($path = $t['path'])) $path = "/";
 	if ($t['query']) $path .= "?" .$t['query'];
 
-	$f = lance_requete($method, $scheme, $host, $path, $port, $noproxy, $refuse_gz, $referer, $datas, $vers);
+	$f = lance_requete($method, $scheme, $user, $host, $path, $port, $noproxy, $refuse_gz, $referer, $datas, $vers);
 	if (!$f) {
 	  // fallback : fopen
 		if (!$GLOBALS['tester_proxy']) {
@@ -559,12 +577,14 @@ function init_http($method, $url, $refuse_gz=false, $referer = '', $datas="", $v
 }
 
 // http://doc.spip.org/@lance_requete
-function lance_requete($method, $scheme, $host, $path, $port, $noproxy, $refuse_gz=false, $referer = '', $datas="", $vers="HTTP/1.0") {
+function lance_requete($method, $scheme, $user, $host, $path, $port, $noproxy, $refuse_gz=false, $referer = '', $datas="", $vers="HTTP/1.0") {
 
 	$http_proxy = need_proxy($host);
 
 	if ($http_proxy) {
-		$path = "$scheme://$host" . (($port != 80) ? ":$port" : "") . $path;
+		$path = "$scheme://"
+			. (!$user ? '' : urlencode($user[0]).":".urlencode($user[1])."@")
+			. "$host" . (($port != 80) ? ":$port" : "") . $path;
 		$t2 = @parse_url($http_proxy);
 		$proxy_user = $t2['user'];
 		$proxy_pass = $t2['pass'];
@@ -584,6 +604,8 @@ function lance_requete($method, $scheme, $host, $path, $port, $noproxy, $refuse_
 	. "User-Agent: SPIP-".$GLOBALS['spip_version_affichee']." (http://www.spip.net/)\r\n"
 	. ($refuse_gz ? '' : "Accept-Encoding: gzip\r\n")
 	. (!$site ? '' : "Referer: $site/$referer\r\n")
+	. (!$user ? '' : "Authorization: Basic "
+	     . base64_encode(urlencode($user[0]).":".urlencode($user[1])) ."\r\n")
 	. (!$proxy_user ? '' :
 	    ("Proxy-Authorization: Basic "
 	     . base64_encode($proxy_user . ":" . $proxy_pass) . "\r\n"));
