@@ -44,19 +44,40 @@ function get_spip_doc($fichier) {
 	return $fichier;
 }
 
-// Filtre pour #ID_DOCUMENT ou #FICHIER
+// Constante indiquant le charset probable des documents non utf-8 joints
+
+@define('CHARSET_JOINT', 'iso-8859-1');
+
+// Filtre pour #FICHIER permettant d'incruster le contenu d'un document
+// Si 2e arg fourni, conversion dans le charset du site si possible
 
 // http://doc.spip.org/@contenu_document
-function contenu_document($arg)
+function contenu_document($arg, $charset='')
 {
 	if (is_numeric($arg)) {
 		$r = sql_fetsel("fichier,distant", "spip_documents", "id_document=".sql_quote($arg));
 		if (!$r) return '';
 		$f = $r['fichier'];
-		$f = ($r['distant'] =='oui') ? copie_locale($f) : get_spip_doc($f);
-	} else if (!$f = copie_locale($arg)) return '';
+		$f = ($r['distant'] =='oui') ? _DIR_RACINE . copie_locale($f) : get_spip_doc($f);
+	}
+	else {
+		if (!@file_exists($f=$arg)){
+			if (!$f = copie_locale($f))
+				return '';
+			$f = _DIR_RACINE . $f;
+		}
+	}
 
-	return spip_file_get_contents($f);
+	$r = spip_file_get_contents($f);
+	
+	if ($charset) {
+		include_spip('inc/charset');
+		if ($charset !== 'auto') {
+			$r = importer_charset($r, $charset);
+		} elseif ($GLOBALS['meta']['charset'] == 'utf-8' AND !is_utf8($r))
+			$r = importer_charset($r, CHARSET_JOINT);
+	}
+	return $r;
 }
 
 // http://doc.spip.org/@generer_url_document_dist
