@@ -61,20 +61,48 @@ function filtre_text_csv_dist($t)
 				str_replace("\n", "<br />", 
 					    substr($cell,1,-1))),
 			$t);
-	list($entete, $corps) = split("\n",$t,2);
+	list($entete, $corps) = preg_split(',\n,',$t,2);
 	$caption = '';
 	// sauter la ligne de tete formee seulement de separateurs 
 	if (substr_count($entete, $sep) == strlen($entete)) {
-		list($entete, $corps) = split("\n",$corps,2);
+		list($entete, $corps) = preg_split(',\n,',$corps,2);
 	}
 	// si une seule colonne, en faire le titre
 	if (preg_match("/^([^$sep]+)$sep+\$/", $entete, $l)) {
 			$caption = "\n||" .  $l[1] . "|";
-			list($entete, $corps) = split("\n",$corps,2);
+			list($entete, $corps) = preg_split(',\n,',$corps,2);
 	}
 	// si premiere colonne vide, le raccourci doit quand meme produire <th...
 	if ($entete[0] == $sep) $entete = ' ' . $entete;
-	if ($corps[strlen($corps)-1] <> "\n") $corps .= "\n";
+
+	$lignes = preg_split(',\n,', $corps);
+	// retrait des lignes vides finales
+	while(preg_match("/^$sep*$/", $lignes[count($lignes)-1]))
+	  unset($lignes[count($lignes)-1]);
+	//  calcul du  nombre de colonne a chaque ligne
+	$nbcols = array();
+	$max = $mil = substr_count($entete, $sep);
+	foreach($lignes as $k=>$v) {
+	  if ($max <> ($nbcols[$k]= substr_count($v, $sep))) {
+	    if ($max > $nbcols[$k])
+	      $mil = $nbcols[$k];
+	    else { $mil = $max; $max = $nbcols[$k];}
+	  }
+	}
+	// Si pas le meme nombre, cadrer au nombre max
+	if ($mil <> $max)
+	  foreach($nbcols as $k=>$v) {
+	    if ($v < $max) $lignes[$k].= str_repeat($sep, $max-$v);
+	    }
+	// et retirer les colonnes integralement vides
+	while(true) {
+	  $nbcols =  ($entete[strlen($entete)-1]===$sep);
+	  foreach($lignes as $v) $nbcols &= ($v[strlen($v)-1]===$sep);
+	  if (!$nbcols) break;
+	  $entete = substr($entete,0,-1);
+	  foreach($lignes as $k=>$v) $lignes[$k] = substr($v,0,-1);
+	}
+	$corps = join("\n", $lignes) . "\n";
 	return propre($caption .
 		"\n|{{" .
 		str_replace($sep,'}}|{{',$entete) .
@@ -291,7 +319,7 @@ function image_bg ($img, $couleur, $pos="") {
 	if (!function_exists("imagecreatetruecolor")
 		OR !($image = image_aplatir(image_sepia($img, $couleur),"gif","cccccc", 64, true))
 	)
-		return "background-color: #$couleur;";
+		return $couleur ? "background-color: #$couleur;" : '';
 	include_spip('inc/filtres_images_etendus');
 	return "background: url(".url_absolue(extraire_attribut($image, "src")).") $pos;";
 }
@@ -1282,17 +1310,26 @@ function extra($letexte, $champ) {
 function post_autobr($texte, $delim="\n_ ") {
 	$texte = str_replace("\r\n", "\r", $texte);
 	$texte = str_replace("\r", "\n", $texte);
+
+	if (preg_match(",\n+$,", $texte, $fin))
+		$texte = substr($texte, 0, -strlen($fin = $fin[0]));
+	else
+		$fin = '';
+
 	$texte = echappe_html($texte, '', true);
 
+
 	$debut = '';
 	$suite = $texte;
 	while ($t = strpos('-'.$suite, "\n", 1)) {
 		$debut .= substr($suite, 0, $t-1);
 		$suite = substr($suite, $t);
 		$car = substr($suite, 0, 1);
-		if (($car<>'-') AND ($car<>'_') AND ($car<>"\n") AND ($car<>"|"))
+		if (($car<>'-') AND ($car<>'_') AND ($car<>"\n") AND ($car<>"|") AND ($car<>"}")
+		AND !preg_match(',^\s*(\n|</?(quote|div)|$),S',($suite))
+		AND !preg_match(',</?(quote|div)> *$,iS', $debut)) {
 			$debut .= $delim;
-		else
+		} else
 			$debut .= "\n";
 		if (preg_match(",^\n+,", $suite, $regs)) {
 			$debut.=$regs[0];
@@ -1302,7 +1339,7 @@ function post_autobr($texte, $delim="\n_ ") {
 	$texte = $debut.$suite;
 
 	$texte = echappe_retour($texte);
-	return $texte;
+	return $texte.$fin;
 }
 
 
@@ -1465,7 +1502,7 @@ function inserer_attribut($balise, $attribut, $val, $texte_backend=true, $vider=
 	if ($vider AND strlen($val)==0)
 		$insert = '';
 	else
-		$insert = " $attribut='$val' ";
+		$insert = " $attribut='$val'";
 
 	list($old, $r) = extraire_attribut($balise, $attribut, true);
 
@@ -1475,11 +1512,11 @@ function inserer_attribut($balise, $attribut, $val, $texte_backend=true, $vider=
 	}
 	else {
 		// preferer une balise " />" (comme <img />)
-		if (preg_match(',[[:space:]]/>,S', $balise))
-			$balise = preg_replace(",[[:space:]]/>,S", $insert."/>", $balise, 1);
+		if (preg_match(',/>,', $balise))
+			$balise = preg_replace(",\s?/>,S", $insert." />", $balise, 1);
 		// sinon une balise <a ...> ... </a>
 		else
-			$balise = preg_replace(",>,", $insert.">", $balise, 1);
+			$balise = preg_replace(",\s?>,S", $insert.">", $balise, 1);
 	}
 
 	return $balise;
@@ -1733,47 +1770,68 @@ function regledetrois($a,$b,$c)
 }
 
 // Fournit la suite de Input-Hidden correspondant aux parametres de
-// l'URL donnee en argument
-// Compatible avec les type_url depuis [13939].
+// l'URL donnee en argument, compatible avec les types_urls depuis [14444].
+// S'il s'agit de l'URL de la page d'appel, 
+// il sait retrouver les parametres implicites des types_urls cryptiques.
+// Si c'est un type_url cryptique sur autre chose, c'est parfois incomplet.
+// cf. tests/filtres/form_hidden.html
 // http://doc.spip.org/@form_hidden
 function form_hidden($action) {
-	$hidden = array();
+	static $uri = '';
+  
+	if (!$uri) $uri = url_absolue(nettoyer_uri());
 	$contexte = array();
-	if (!strpos($action, 'page=')
+	if ($uri == url_absolue($action)
 	AND $renommer = generer_url_entite()
-	AND $p = $renommer($action, $contexte)) {
-
+	AND $p = $renommer($action, $contexte)
+	AND $p[3]) {
 		$contexte = $p[0];
 		$contexte['page'] = $p[3];
-		$action = preg_replace('/[?][^&]*/', '', $action);
+		$action = preg_replace('/^([^?]*)[?][^&]*/', '\1', $action);
 	}
+
+	// on va remplir un tableau de valeurs en prenant bien soin de ne pas
+	// ecraser les elements de la forme mots[]=1&mots[]=2
+	$values = array();
+
+	// d'abord avec celles de l'url
 	if (false !== ($p = strpos($action, '?'))) {
 		foreach(preg_split('/&(amp;)?/S',substr($action,$p+1)) as $c){
 			list($var,$val) = explode('=', $c, 2);
-			if ($var) $contexte[$var] = $val;
+			if ($var) {
+				$val =  rawurldecode($val);
+				if (preg_match(',\[\]$,S', $var))
+					$values[] = array($var, $val);
+				else if (!isset($values[$var]))
+					$values[$var] = array($var, $val);
+			}
 		}
 	}
-	foreach($contexte as $var => $val) {
-		$input = '<input name="'
+
+	// ensuite avec celles du contexte, sans doublonner !
+	foreach($contexte as $var=>$val)
+		if (preg_match(',\[\]$,S', $var))
+			$values[] = array($var, $val);
+		else if (!isset($values[$var]))
+			$values[$var] = array($var, $val);
+
+	// puis on rassemble le tout
+	$hidden = array();
+	foreach($values as $value) {
+		list($var,$val) = $value;
+		$hidden[] = '<input name="'
 			. entites_html($var)
 			.'"'
 			. (is_null($val)
 				? ''
-				: ' value="'.entites_html(rawurldecode($val)).'"'
+				: ' value="'.entites_html($val).'"'
 				)
 			. ' type="hidden" />';
-
-		// si c'est une variable de la forme a[]=2, cumuler les input
-		// sinon ne conserver que le premier
-		if (preg_match(',\[\]$,S', $var))
-			$hidden[] = $input;
-		else
-			if (!isset($hidden[$var]))
-				$hidden[$var] = $input;
 	}
 	return join("\n", $hidden);
 }
 
+
 // http://doc.spip.org/@filtre_bornes_pagination_dist
 function filtre_bornes_pagination_dist($courante, $nombre, $max = 10) {
 	if($max<=0 OR $max>=$nombre)
@@ -1833,13 +1891,6 @@ function filtre_pagination_dist($total, $nom, $position, $pas, $liste = true, $m
 	$debut = 'debut'.$nom; // 'debut_articles'
 	$ancre = 'pagination'.$nom; // #pagination_articles
 
-	// Si le contexte ne contient pas de debut_xx, on regarde les globales
-	// (de facon a permettre la pagination dans les modeles) ; c'est une
-	// legere entorse au schema de base (squelette+contexte => page), mais
-	// sinon il faut une usine a gaz pour passer debut_xx dans propre()...
-	if ($position === NULL)
-		$position = _request($debut);
-
 	// n'afficher l'ancre qu'une fois
 	if (!isset($ancres[$ancre]))
 		$bloc_ancre = $ancres[$ancre] = "<a name='$ancre' id='$ancre'></a>";
@@ -2193,7 +2244,7 @@ function compacte($source, $format = null) {
 	AND preg_match(',\.'.$format.'$,i', $source, $r)
 	AND file_exists($source)) {
 		// si c'est une css, il faut reecrire les url en absolu
-  	if ($type=='css')
+  	if ($format=='css')
   		$source = url_absolue_css($source);
 		
 		$f = basename($source,'.'.$format);
@@ -2614,4 +2665,39 @@ function _xor($message, $key=null){
 	return $message;
 }
 
+
+/**
+ * filtre explode pour les squelettes permettant d'ecrire
+ * #GET{truc}|explode{-}
+ *
+ * @param strong $a
+ * @param string $b
+ * @return array
+ */
+function filtre_explode_dist($a,$b){return explode($b,$a);}
+
+/**
+ * filtre implode pour les squelettes permettant d'ecrire
+ * #GET{truc}|implode{-}
+ *
+ * @param array $a
+ * @param string $b
+ * @return string
+ */
+function filtre_implode_dist($a,$b){return implode($b,$a);}
+
+/*
+ * Deux verrues pour que le pipeline de revisions soit correct
+ * elles vont sauter quand ca passera en plugin
+ */
+function premiere_revision($x) {
+	include_spip('inc/revisions');
+	return enregistrer_premiere_revision($x);
+}
+function nouvelle_revision($x) {
+	include_spip('inc/revisions');
+	return enregistrer_nouvelle_revision($x);
+}
+
+
 ?>
