@@ -2217,12 +2217,25 @@ function rtl_visuel($texte, $rtl_global) {
 		$mot = preg_replace(",٨,u", "^٨^", $mot);
 		$mot = preg_replace(",٩,u", "^٩^", $mot);
 
+		
+		// accents (enfin, pas exactement)
+				
+		$mot = preg_replace(",\^ّ,u", "ّ^", $mot);
+		$mot = preg_replace(",\^ْ,u", "ْ^", $mot);
+		$mot = preg_replace(",\^ِ,u", "ِ^", $mot);
+		$mot = preg_replace(",\^َ,u", "َ^", $mot);
+		$mot = preg_replace(",\^ً,u", "ً^", $mot);
+		$mot = preg_replace(",\^ٍ,u", "ٍ^", $mot);
+		$mot = preg_replace(",\^ُ,u", "ُ^", $mot);
+		$mot = preg_replace(",\^ٌ,u", "ٌ^", $mot);
+	
 
 		// Ligatures
 		$mot = preg_replace(",لا,u", "ﻻ", $mot);
 		$mot = preg_replace(",لأ,u", "ﻷ", $mot);
 		
 		
+		
 		foreach ($arabic_letters as $a_l) {
 			$mot = preg_replace(",([^\^])".$a_l[0]."([^\^]),u", "\\1".$a_l[3]."\\2", $mot);
 			$mot = preg_replace(",\^".$a_l[0]."([^\^]),u", "^".$a_l[2]."\\1", $mot);
