@@ -23,7 +23,7 @@ if (!defined("_ECRIRE_INC_VERSION")) return;
 // http://doc.spip.org/@charger_fonction
 function charger_fonction($nom, $dossier='exec', $continue=false) {
 
-	if (substr($dossier,-1) != '/') $dossier .= '/';
+	if (strlen($dossier) AND substr($dossier,-1) != '/') $dossier .= '/';
 
 	if (function_exists($f = str_replace('/','_',$dossier) . $nom))
 		return $f;
@@ -37,9 +37,10 @@ function charger_fonction($nom, $dossier='exec', $continue=false) {
 
 	// passer en minuscules (cf les balises de formulaires)
 	// et inclure le fichier
-	if (!$inc = include_spip($dossier.($d = strtolower($nom))))
+	if (!$inc = include_spip($dossier.($d = strtolower($nom)))
 		// si le fichier truc/machin/nom.php n'existe pas,
 		// la fonction peut etre definie dans truc/machin.php qui regroupe plusieurs petites fonctions
+		AND strlen(dirname($dossier)) AND dirname($dossier)!='.')
 		include_spip(substr($dossier,0,-1));
 	if (function_exists($f)) return $f;
 	if (function_exists($g)) return $g;
@@ -297,7 +298,7 @@ function parametre_url($url, $c, $v=NULL, $sep='&amp;') {
 		  if (!is_array($v))
 		    $url[] = $k .'=' . $u;
 		  else {
-		    $id = (substr($k,-2) != '[]') ? $k : ($k ."[]");
+		    $id = (substr($k,-2) == '[]') ? $k : ($k ."[]");
 		    foreach ($v as $w) $url[]= $id .'=' . $w;
 		  }
 		}
@@ -772,9 +773,9 @@ function generer_url_entite($id='', $entite='', $args='', $ancre='', $public=NUL
 				:  $GLOBALS['type_urls']; // pour SPIP <2
 			}
 
-			$f = charger_fonction($type, 'urls', true); 
+			$f = charger_fonction($type, 'urls', true);
 		// si $entite='', on veut la fonction de passage URL ==> id
-			if (!$entite) return $f; 
+			if (!$entite) return $f;
 		// sinon on veut effectuer le passage id ==> URL
 			$res = !$f ? '' : $f(intval($id), $entite, $args, $ancre);
 		}
@@ -892,7 +893,7 @@ function generer_url_ecrire($script='', $args="", $no_entities=false, $rel=false
 		$rel = _DIR_RESTREINT ? _DIR_RESTREINT :
 			('./'  . _SPIP_ECRIRE_SCRIPT);
 
-	@list($script, $ancre) = split('#', $script);
+	@list($script, $ancre) = explode('#', $script);
 	if ($script AND ($script<>'accueil' OR $rel))
 		$args = "?exec=$script" . (!$args ? '' : "&$args");
 	elseif ($args)
@@ -983,7 +984,7 @@ function generer_form_action($script, $corps, $atts='', $public=false) {
 	// si l'on est dans l'espace prive, on garde dans l'url
 	// l'exec a l'origine de l'action, qui permet de savoir si il est necessaire
 	// ou non de proceder a l'authentification (cas typique de l'install par exemple)
-	$h = (_DIR_RACINE AND !$public) 
+	$h = (_DIR_RACINE AND !$public)
 	? generer_url_ecrire(_request('exec'))
 	: generer_url_public();
 
@@ -1008,7 +1009,7 @@ function generer_url_action($script, $args="", $no_entities=false , $public = fa
 	  :  generer_url_public();
 	$url = parametre_url($url,'action',$script);
 	if ($args) $url .= quote_amp('&'.$args);
-	
+
 	if ($no_entities) $url = str_replace('&amp;','&',$url);
 	return $url;
 }
@@ -1047,7 +1048,7 @@ function spip_initialisation_core($pi=NULL, $pa=NULL, $ti=NULL, $ta=NULL) {
 
 	// Le charset par defaut lors de l'installation
 	define('_DEFAULT_CHARSET', 'utf-8');
-	
+
 	define('_DIR_IMG', $pa);
 	define('_DIR_LOGOS', $pa);
 	define('_DIR_IMG_ICONES', _DIR_LOGOS . "icones/");
@@ -1108,7 +1109,7 @@ function spip_initialisation_core($pi=NULL, $pa=NULL, $ti=NULL, $ta=NULL) {
 
 	// Se mefier des fichiers mal remplis!
 	if (!defined('_SPIP_CHMOD')) define('_SPIP_CHMOD', 0777);
-	
+
 	// le nom du repertoire plugins/
 	define('_DIR_PLUGINS', _DIR_RACINE . "plugins/");
 
@@ -1123,7 +1124,7 @@ function spip_initialisation_core($pi=NULL, $pa=NULL, $ti=NULL, $ta=NULL) {
 		define('_SPIP_LOCK_MODE',1); // utiliser le flock php
 		#define('_SPIP_LOCK_MODE',2); // utiliser le nfslock de spip mais link() est tres souvent interdite
 	}
-		
+
 	//
 	// Module de lecture/ecriture/suppression de fichiers utilisant flock()
 	// (non surchargeable en l'etat ; attention si on utilise include_spip()
@@ -1167,7 +1168,6 @@ function spip_initialisation_core($pi=NULL, $pa=NULL, $ti=NULL, $ta=NULL) {
 	//
 	// Capacites php (en fonction de la version)
 	//
-	$GLOBALS['flag_gz'] = function_exists("gzencode"); #php 4.0.4
 	$GLOBALS['flag_ob'] = (function_exists("ob_start")
 		&& function_exists("ini_get")
 		&& !strstr(@ini_get('disable_functions'), 'ob_'));
@@ -1238,7 +1238,7 @@ function spip_initialisation_suite() {
 	define('_IMG_MAX_WIDTH', 0); # largeur en pixels
 	define('_IMG_MAX_HEIGHT', 0); # hauteur en pixels
 
-	define('_COPIE_LOCALE_MAX_SIZE',2097152); // poids en octet
+	define('_COPIE_LOCALE_MAX_SIZE',16777216); // poids en octet
 
 	// qq chaines standard
 	define('_ACCESS_FILE_NAME', '.htaccess');
@@ -1326,7 +1326,7 @@ function spip_initialisation_suite() {
 		else
 			define('_INTERDIRE_COMPACTE_HEAD_ECRIRE',true); // evite une page blanche car on ne saura pas calculer la css dans ce hit
 	}
-	
+
 	init_var_mode();
 }
 
@@ -1347,7 +1347,7 @@ function init_var_mode(){
 			if ($_GET['var_mode'] == 'calcul'
 			OR $_GET['var_mode'] == 'recalcul')
 				$GLOBALS['var_mode'] = $_GET['var_mode'];
-		
+
 			// preview, debug, blocs, urls et images necessitent une autorisation
 			else if (in_array($_GET['var_mode'],array('preview','debug','inclure','urls','images'))) {
 				include_spip('inc/autoriser');
@@ -1360,7 +1360,7 @@ function init_var_mode(){
 						case 'preview':
 							// forcer le compilo et ignorer les caches existants
 							$GLOBALS['var_mode'] = 'recalcul';
-							// truquer les boucles 
+							// truquer les boucles
 							$GLOBALS['var_preview'] = true;
 							// et ne pas enregistrer de cache
 							$GLOBALS['var_nocache'] = true;
@@ -1582,13 +1582,19 @@ function recuperer_fond($fond, $contexte=array(), $options = array(), $connect='
 	// (trim etait le 3eme argument, par defaut a true)
 	if (!is_array($options)) $options = array('trim'=>$options);
 	if (!isset($options['trim'])) $options['trim']=true;
+
+	if (isset($contexte['connect'])){
+		$connect = ($connect ? $connect : $contexte['connect']);
+		unset($contexte['connect']);
+	}
+
 	if (isset($options['modele']))
 		$contexte = creer_contexte_de_modele($contexte);
 
 	$texte = "";
 	$pages = array();
 	if (isset($contexte['fond'])
-	 // securite anti injection pour permettre aux plugins de faire 
+	 // securite anti injection pour permettre aux plugins de faire
 	 // des interfaces avec simplement recuperer_fond($fond,$_GET);
 	 AND $contexte['fond']!==_request('fond'))
 		$fond = $contexte['fond'];
@@ -1598,7 +1604,7 @@ function recuperer_fond($fond, $contexte=array(), $options = array(), $connect='
 		// Si on a inclus sans fixer le critere de lang, on prend la langue courante
 		if (!isset($contexte['lang']))
 			$contexte['lang'] = $GLOBALS['spip_lang'];
-	
+
 		if ($contexte['lang'] != $GLOBALS['meta']['langue_site']) {
 			$lang_select = lang_select($contexte['lang']);
 		}
@@ -1610,7 +1616,7 @@ function recuperer_fond($fond, $contexte=array(), $options = array(), $connect='
 		$page = evaluer_fond($f, $contexte, $connect);
 		if (isset($options['ajax'])AND $options['ajax'])
 			$page['texte'] = encoder_contexte_ajax(array_merge($contexte,array('fond'=>$f)),'',$page['texte']);
-			
+
 		if ($GLOBALS['var_inclure'])
 			$page['texte'] = "<fieldset class='blocs'><legend>".$page['sourcefile']."</legend>".$page['texte']."</fieldset>";
 		$page = pipeline('recuperer_fond',array(
@@ -1625,7 +1631,7 @@ function recuperer_fond($fond, $contexte=array(), $options = array(), $connect='
 
 	$GLOBALS['_INC_PUBLIC']--;
 
-	if ($lang_select) lang_select();	
+	if ($lang_select) lang_select();
 	if (isset($options['raw']) AND $options['raw'])
 		return is_array($fond)?$pages:reset($pages);
 	else
