@@ -126,8 +126,8 @@ function spip_mysql_query($query, $serveur='',$requeter=true) {
 	$t = !isset($_GET['var_profile']) ? 0 : trace_query_start();
 	$r = $link ? mysql_query($query, $link) : mysql_query($query);
 
-	if ($e = spip_mysql_errno())	// Log de l'erreur eventuelle
-		$e .= spip_mysql_error($query); // et du fautif
+	if ($e = spip_mysql_errno($serveur))	// Log de l'erreur eventuelle
+		$e .= spip_mysql_error($query, $serveur); // et du fautif
 	return $t ? trace_query_end($query, $t, $r, $e, $serveur) : $r;
 }
 
@@ -185,8 +185,8 @@ function spip_mysql_select($select, $from, $where='',
 	if (!($res = spip_mysql_query($query, $serveur, $requeter))) {
 		include_spip('public/debug');
 		erreur_requete_boucle(substr($query, 7),
-				      spip_mysql_errno(),
-				      spip_mysql_error($query) );
+				      spip_mysql_errno($serveur),
+				      spip_mysql_error($query, $serveur) );
 	}
 
 	return $res;
@@ -270,7 +270,8 @@ function spip_mysql_select_as($args)
 // Changer les noms des tables ($table_prefix)
 // Quand tous les appels SQL seront abstraits on pourra l'ameliorer
 
-// http://doc.spip.org/@traite_query
+define('_SQL_PREFIXE_TABLE', '/([,\s])spip_/S');
+
 function traite_query($query, $db='', $prefixe='') {
 
 	if ($GLOBALS['mysql_rappel_nom_base'] AND $db)
@@ -280,12 +281,16 @@ function traite_query($query, $db='', $prefixe='') {
 	if ($prefixe)
 		$pref .= $prefixe . "_";
 
-	if (preg_match('/\s(SET|VALUES|WHERE|DATABASE)\s/i', $query, $regs)) {
+	if (!preg_match('/\s(SET|VALUES|WHERE|DATABASE)\s/i', $query, $regs)) {
+		$suite ='';
+	} else {
 		$suite = strstr($query, $regs[0]);
 		$query = substr($query, 0, -strlen($suite));
-	} else $suite ='';
-
-	$r = preg_replace('/([,\s])spip_/', '\1'.$pref, $query) . $suite;
+		if (preg_match('/^(.*?)([(]\s*SELECT\b.*)$/si', $suite, $r)) {
+		  $suite = $r[1] . traite_query($r[2], $db, $prefixe);
+		}
+	}
+	$r = preg_replace(_SQL_PREFIXE_TABLE, '\1'.$pref, $query) . $suite;
 #	spip_log("traite_query: " . substr($r,0, 50) . ".... $db, $prefixe");
 	return $r;
 }
@@ -502,9 +507,12 @@ function spip_mysql_countsel($from = array(), $where = array(),
 	return $c;
 }
 
+// Bien specifier le serveur auquel on s'adresse,
+// mais a l'install la globale n'est pas encore completement definie
 // http://doc.spip.org/@spip_mysql_error
 function spip_mysql_error($query='', $serveur='',$requeter=true) {
-	$s = mysql_error();
+	$link = $GLOBALS['connexions'][$serveur ? $serveur : 0]['link'];
+	$s = $link ? mysql_error($link) : mysql_error();
 	if ($s) spip_log("$s - $query", 'mysql');
 	return $s;
 }
@@ -512,7 +520,8 @@ function spip_mysql_error($query='', $serveur='',$requeter=true) {
 // A transposer dans les portages
 // http://doc.spip.org/@spip_mysql_errno
 function spip_mysql_errno($serveur='',$requeter=true) {
-	$s = mysql_errno();
+	$link = $GLOBALS['connexions'][$serveur ? $serveur : 0]['link'];
+	$s = $link ? mysql_errno($link) : mysql_errno();
 	// 2006 MySQL server has gone away
 	// 2013 Lost connection to MySQL server during query
 	if (in_array($s, array(2006,2013)))
@@ -549,8 +558,8 @@ function spip_mysql_insert($table, $champs, $valeurs, $desc='', $serveur='',$req
 	if (mysql_query($query, $link))
 		$r = mysql_insert_id($link);
 	else {
-	  if ($e = spip_mysql_errno())	// Log de l'erreur eventuelle
-		$e .= spip_mysql_error($query); // et du fautif
+	  if ($e = spip_mysql_errno($serveur))	// Log de l'erreur eventuelle
+		$e .= spip_mysql_error($query, $serveur); // et du fautif
 	}
 	return $t ? trace_query_end($query, $t, $r, $e, $serveur) : $r;
 
@@ -634,10 +643,16 @@ function spip_mysql_updateq($table, $champs, $where='', $desc=array(), $serveur=
 
 // http://doc.spip.org/@spip_mysql_delete
 function spip_mysql_delete($table, $where='', $serveur='',$requeter=true) {
-	return spip_mysql_query(
+	$res = spip_mysql_query(
 			  calculer_mysql_expression('DELETE FROM', $table, ',')
 			. calculer_mysql_expression('WHERE', $where),
 			$serveur, $requeter);
+	if ($res){
+		$link = $GLOBALS['connexions'][$serveur ? $serveur : 0]['link'];
+		return $link ? mysql_affected_rows($link) : mysql_affected_rows();
+	}
+	else
+		return false;
 }
 
 // http://doc.spip.org/@spip_mysql_replace
@@ -660,24 +675,28 @@ function spip_mysql_replace_multi($table, $tab_couples, $desc=array(), $serveur=
 
 // http://doc.spip.org/@spip_mysql_multi
 function spip_mysql_multi ($objet, $lang) {
-	$retour = "(TRIM(IF(INSTR(".$objet.", '<multi>') = 0 , ".
+	$lengthlang = strlen("[$lang]");
+	$posmulti = "INSTR(".$objet.", '<multi>')";
+	$posfinmulti = "INSTR(".$objet.", '</multi>')";
+	$debutchaine = "LEFT(".$objet.", $posmulti-1)";
+	$finchaine = "RIGHT(".$objet.", CHAR_LENGTH(".$objet.") -(7+$posfinmulti))";
+	$chainemulti = "TRIM(SUBSTRING(".$objet.", $posmulti+7, $posfinmulti -(7+$posmulti)))";
+	$poslang = "INSTR($chainemulti,'[".$lang."]')";
+	$poslang = "IF($poslang=0,INSTR($chainemulti,']')+1,$poslang+$lengthlang)";
+	$chainelang = "TRIM(SUBSTRING(".$objet.", $posmulti+7+$poslang-1,$posfinmulti -($posmulti+7+$poslang-1) ))";
+	$posfinlang = "INSTR(".$chainelang.", '[')";
+	$chainelang = "IF($posfinlang>0,LEFT($chainelang,$posfinlang-1),$chainelang)";
+	//$chainelang = "LEFT($chainelang,$posfinlang-1)";
+	$retour = "(TRIM(IF($posmulti = 0 , ".
 		"     TRIM(".$objet."), ".
 		"     CONCAT( ".
-		"          LEFT(".$objet.", INSTR(".$objet.", '<multi>')-1), ".
+		"          $debutchaine, ".
 		"          IF( ".
-		"               INSTR(TRIM(RIGHT(".$objet.", CHAR_LENGTH(".$objet.") -(6+INSTR(".$objet.", '<multi>')))),'[".$lang."]') = 0, ".
-		"               IF( ".
-		"                     TRIM(RIGHT(".$objet.", CHAR_LENGTH(".$objet.") -(6+INSTR(".$objet.", '<multi>')))) REGEXP '^\\[[a-z\_]{2,}\\]', ".
-		"                     INSERT( ".
-		"                          TRIM(RIGHT(".$objet.", CHAR_LENGTH(".$objet.") -(6+INSTR(".$objet.", '<multi>')))), ".
-		"                          1, ".
-		"                          INSTR(TRIM(RIGHT(".$objet.", CHAR_LENGTH(".$objet.") -(6+INSTR(".$objet.", '<multi>')))), ']'), ".
-		"                          '' ".
-		"                     ), ".
-		"                     TRIM(RIGHT(".$objet.", CHAR_LENGTH(".$objet.") -(6+INSTR(".$objet.", '<multi>')))) ".
-		"                ), ".
-		"               TRIM(RIGHT(".$objet.", ( CHAR_LENGTH(".$objet.") - (INSTR(".$objet.", '[".$lang."]')+ CHAR_LENGTH('[".$lang."]')-1) ) )) ".
-		"          ) ".
+		"               $poslang = 0, ".
+		"                     $chainemulti, ".
+		"               $chainelang".
+		"          ), ". 
+		"          $finchaine".
 		"     ) ".
 		"))) AS multi";
 
@@ -690,10 +709,9 @@ function spip_mysql_hex($v)
 	return "0x" . $v;
 }
 
-// http://doc.spip.org/@spip_mysql_quote
-function spip_mysql_quote($v)
+function spip_mysql_quote($v, $type='')
 {
-	return _q($v);
+	return ($type === 'int' AND !$v) ? '0' :  _q($v);
 }
 
 //
